@@ -4,10 +4,13 @@ import logging
 
 import numpy as np
 from scipy import sparse as sp
+from rdkit import Chem
 
 from ..readers import Mol2, Mol2Block
 from ..readers import Smiles
 from ..readers import PDB, PartialPDB, PDBBB
+from ..readers import CanonicalAtomOrderConverter
+from ..readers.readmol import MolReader, MolBlock
 
 
 class TestReadingMol2File(unittest.TestCase):
@@ -144,9 +147,9 @@ class TestMol2(TestReadingMol2File):
         can_smiles = self.mol.to_smiles()
         iso_smiles = self.mol.to_smiles(isomeric=True)
         self.assertEqual(len(can_smiles), self.mol.n_mols)
-        self.assertEqual(can_smiles[0], r"C[NH+](C)CCNC(=O)C1:N:O:N:C:1N")
+        self.assertEqual(can_smiles[0], r"C[NH+](C)CCNC(=O)c1nonc1N")
         self.assertEqual(len(iso_smiles), self.mol.n_mols)
-        self.assertEqual(iso_smiles[62], r"CN1:C:N:C:C:1[C@H]([NH3+])C1(O)CNC1")
+        self.assertEqual(iso_smiles[62], r"Cn1cncc1[C@H]([NH3+])C1(O)CNC1")
         self.assertNotEqual(can_smiles[1], iso_smiles[1])
 
     def test_molecular_weights(self):
@@ -316,6 +319,16 @@ class TestReadingSmiles(unittest.TestCase):
         # with self.assertRaises(ValueError):
         #     self.sm.get_bond_features(padding=12)
 
+    def test_sorted_bond_features(self):
+        feats = self.sm.get_bond_features(sort_atoms=True)
+        self.assertEqual(len(feats), 26)
+        self.assertEqual(feats["0-5"], "1")
+        with self.assertRaises(KeyError):
+            feats["0-1"]
+        unsorted_feats = self.sm.get_bond_features(sort_atoms=False)
+        self.assertEqual(len(unsorted_feats), 26)
+        self.assertEqual(unsorted_feats["0-1"], "1")
+
     def test_graph(self):
         graph = self.sm.to_graph()
         self.assertEqual(len(graph), 3)
@@ -403,3 +416,74 @@ class TestReadPDB(unittest.TestCase):
         self.assertEqual(atom_features[-1][:3], [-14.909, -4.100, 8.772])
         self.assertEqual(len(atom_features), adj.shape[0])
         self.assertEqual(len(atom_features[0]), 5)
+
+
+class TestReadMol(unittest.TestCase):
+    def setUp(self):
+        self.fpath = os.path.join(
+            "chemreader", "tests", "testing_resources", "test_mol_reader.mol"
+        )
+
+    def test_block_reading(self):
+        reader = MolReader(self.fpath)
+        self.assertEqual(reader.n_mols, 3)
+        self.assertIsInstance(reader.blocks, list)
+        self.assertEqual(len(reader.blocks), 3)
+
+        block = MolBlock(reader.blocks[0])
+        self.assertIsInstance(block.rdkit_mol, Chem.rdchem.Mol)
+        self.assertEqual(block.rdkit_mol.GetNumAtoms(), 24)
+        self.assertEqual(block.rdkit_mol.GetNumBonds(), 26)
+        adj = block.get_adjacency_matrix(sparse=False)
+        self.assertEqual(adj.shape, (24, 24))
+        sparse_adj = block.get_adjacency_matrix(sparse=True)
+        self.assertIsInstance(sparse_adj, sp.csr.csr_matrix)
+        atom_features = block.get_atom_features(numeric=False)
+        self.assertEqual(len(atom_features), 24)
+        self.assertEqual(atom_features[21][3], "Cl")
+        atom_features = block.get_atom_features(numeric=True)
+        self.assertEqual(atom_features[21][3], 7)
+
+
+class TestAtomOrderConverter(unittest.TestCase):
+    def setUp(self):
+        dir_path = os.path.dirname(os.path.realpath(__file__))
+        self.mol1 = Chem.MolFromMol2File(
+            os.path.join(dir_path, "testing_resources", "mol_origin.mol2"),
+            removeHs=False,
+        )
+        self.mol2 = Chem.MolFromMol2File(
+            os.path.join(dir_path, "testing_resources", "mol_diff1.mol2"),
+            removeHs=False,
+        )
+        self.mol3 = Chem.MolFromMol2File(
+            os.path.join(dir_path, "testing_resources", "mol_diff2.mol2"),
+            removeHs=False,
+        )
+
+    def test_output_atom_order_are_the_same(self):
+        conv1 = CanonicalAtomOrderConverter(self.mol1)
+        conv2 = CanonicalAtomOrderConverter(self.mol2)
+        conv3 = CanonicalAtomOrderConverter(self.mol3)
+        new_mol1 = conv1.convert()
+        new_mol2 = conv2.convert()
+        new_mol3 = conv3.convert()
+        conf1 = new_mol1.GetConformer(0)
+        conf2 = new_mol2.GetConformer(0)
+        conf3 = new_mol3.GetConformer(0)
+        for idx in range(new_mol1.GetNumAtoms()):
+            a1, a2, a3 = (
+                new_mol1.GetAtomWithIdx(idx),
+                new_mol2.GetAtomWithIdx(idx),
+                new_mol3.GetAtomWithIdx(idx),
+            )
+            self.assertEqual(a1.GetSymbol(), a2.GetSymbol())
+            self.assertEqual(a1.GetSymbol(), a3.GetSymbol())
+            self.assertEqual(a1.GetIdx(), a2.GetIdx())
+            self.assertEqual(a1.GetIdx(), a3.GetIdx())
+            pos1 = conf1.GetAtomPosition(a1.GetIdx())
+            pos2 = conf2.GetAtomPosition(a2.GetIdx())
+            pos3 = conf3.GetAtomPosition(a3.GetIdx())
+            for coor1, coor2, coor3 in zip(pos1, pos2, pos3):
+                self.assertEqual(coor1, coor2)
+                self.assertEqual(coor1, coor3)
